@@ -18,6 +18,10 @@ module Data.Git
     , Tag(..)
     , GitTime
     , ModePerm(..)
+    , EntName
+    , EntPath
+    , entName
+    , entPathAppend
 
     -- * Helper & type related to ModePerm
     , ObjectFileType(..)
@@ -55,6 +59,15 @@ module Data.Git
     , setObject
     , toObject
 
+    -- * Work trees
+    , WorkTree
+    , EntType(..)
+    , workTreeNew
+    , workTreeFrom
+    , workTreeDelete
+    , workTreeSet
+    , workTreeFlush
+
     -- * Named refs
     , branchWrite
     , branchList
@@ -70,3 +83,4 @@ import Data.Git.Storage
 import Data.Git.Repository
 import Data.Git.Revision
 import Data.Git.Storage.Object (toObject)
+import Data.Git.WorkTree
